# Realtime (WebSocket) — Django Developer Reference

- [Architecture & Setup](architecture.md) — Django Channels setup, configuration
- [Publishing Messages](publishing.md) — Server-side publish helpers
- [Instance Hooks](hooks.md) — Model hooks for WebSocket events
